![Upload Python Package](https://github.com/nirmalhk7/veronica-cli/workflows/Upload%20Python%20Package/badge.svg?branch=master)

# veronica-cli

Your faithful Linux Assistant.

## Features Implemented
- *Google Knowledge API*: Run `info SEARCH_TERM` to get relevant information such as the who's, where's and what's.
- *Darksky API*

